# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from libica.openapi.libgds.api_client import ApiClient
from libica.openapi.libgds.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class FilesApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def archive_file(self, file_id, body, **kwargs):  # noqa: E501
        """Archive a file  # noqa: E501

        Archives a file to a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_file(file_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to be archived. (required)
        :param FileArchiveRequest body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.archive_file_with_http_info(file_id, body, **kwargs)  # noqa: E501

    def archive_file_with_http_info(self, file_id, body, **kwargs):  # noqa: E501
        """Archive a file  # noqa: E501

        Archives a file to a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.archive_file_with_http_info(file_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to be archived. (required)
        :param FileArchiveRequest body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method archive_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `archive_file`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `archive_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{fileId}:archive', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def create_file(self, body, **kwargs):  # noqa: E501
        """Create a file entry in GDS and get temporary credentials for upload  # noqa: E501

        Create a file entry in GDS. Returns temporary credentials for file upload directly to S3 when the include=objectStoreAccess parameter is used. Volume ID or volume name is required for file creation. If a folder path is provided and does not exist, GDS creates the folder path in the appropriate account automatically.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_file(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateFileRequest body: (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileWriteableResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.create_file_with_http_info(body, **kwargs)  # noqa: E501

    def create_file_with_http_info(self, body, **kwargs):  # noqa: E501
        """Create a file entry in GDS and get temporary credentials for upload  # noqa: E501

        Create a file entry in GDS. Returns temporary credentials for file upload directly to S3 when the include=objectStoreAccess parameter is used. Volume ID or volume name is required for file creation. If a folder path is provided and does not exist, GDS creates the folder path in the appropriate account automatically.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.create_file_with_http_info(body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param CreateFileRequest body: (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileWriteableResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'body',
            'include'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method create_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `create_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileWriteableResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def delete_file(self, file_id, **kwargs):  # noqa: E501
        """Permanently delete a file  # noqa: E501

        Permanently delete a file entry and its underlying content  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to delete. (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.delete_file_with_http_info(file_id, **kwargs)  # noqa: E501

    def delete_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Permanently delete a file  # noqa: E501

        Permanently delete a file entry and its underlying content  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.delete_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to delete. (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `delete_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{fileId}', 'DELETE',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_file(self, file_id, **kwargs):  # noqa: E501
        """Get details about a file, including a pre-signed URL for download  # noqa: E501

        Get information and details for the specified file ID, including metadata and a pre-signed URL for file download. The URL can be used as a curl command or directly with S3.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to retrieve. (required)
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param str metadata_include: Optional parameter to specify comma separated patterns to include metadata by their field names.
        :param str metadata_exclude: Optional parameter to specify comma separated patterns to exclude metadata by their field names.
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.get_file_with_http_info(file_id, **kwargs)  # noqa: E501

    def get_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Get details about a file, including a pre-signed URL for download  # noqa: E501

        Get information and details for the specified file ID, including metadata and a pre-signed URL for file download. The URL can be used as a curl command or directly with S3.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to retrieve. (required)
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param str metadata_include: Optional parameter to specify comma separated patterns to include metadata by their field names.
        :param str metadata_exclude: Optional parameter to specify comma separated patterns to exclude metadata by their field names.
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id',
            'tenant_id',
            'metadata_include',
            'metadata_exclude'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `get_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501
        if 'metadata_include' in local_var_params and local_var_params['metadata_include'] is not None:  # noqa: E501
            query_params.append(('metadata.include', local_var_params['metadata_include']))  # noqa: E501
        if 'metadata_exclude' in local_var_params and local_var_params['metadata_exclude'] is not None:  # noqa: E501
            query_params.append(('metadata.exclude', local_var_params['metadata_exclude']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{fileId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def list_files(self, **kwargs):  # noqa: E501
        """Get a list of files  # noqa: E501

        Given a volumeId or volume name, get a list of files accessible by the JWT. The default sort returned is alphabetical, ascending. The default page size is 10 items  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_files(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] volume_id: Optional field that specifies comma-separated volume IDs to include in the list
        :param list[str] volume_name: Optional field that specifies comma-separated volume names to include in the list
        :param list[str] path: Optional field that specifies comma-separated paths to include in the list. Value can use wildcards (e.g. /a/b/c/*) or exact matches (e.g. /a/b/c/d/).
        :param bool is_uploaded: Optional field to filter by Uploaded files
        :param str archive_status: Optional field that specifies comma-separated Archive Statuses to include in the list
        :param bool recursive: Optional field to specify if files should be returned recursively in and under the specified paths, or only directly in the specified paths
        :param int page_size: START_DESC END_DESC
        :param str page_token: START_DESC END_DESC
        :param str include: START_DESC END_DESC
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileListResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.list_files_with_http_info(**kwargs)  # noqa: E501

    def list_files_with_http_info(self, **kwargs):  # noqa: E501
        """Get a list of files  # noqa: E501

        Given a volumeId or volume name, get a list of files accessible by the JWT. The default sort returned is alphabetical, ascending. The default page size is 10 items  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.list_files_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] volume_id: Optional field that specifies comma-separated volume IDs to include in the list
        :param list[str] volume_name: Optional field that specifies comma-separated volume names to include in the list
        :param list[str] path: Optional field that specifies comma-separated paths to include in the list. Value can use wildcards (e.g. /a/b/c/*) or exact matches (e.g. /a/b/c/d/).
        :param bool is_uploaded: Optional field to filter by Uploaded files
        :param str archive_status: Optional field that specifies comma-separated Archive Statuses to include in the list
        :param bool recursive: Optional field to specify if files should be returned recursively in and under the specified paths, or only directly in the specified paths
        :param int page_size: START_DESC END_DESC
        :param str page_token: START_DESC END_DESC
        :param str include: START_DESC END_DESC
        :param str tenant_id: Optional parameter to see shared data in another tenant
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileListResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'volume_id',
            'volume_name',
            'path',
            'is_uploaded',
            'archive_status',
            'recursive',
            'page_size',
            'page_token',
            'include',
            'tenant_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method list_files" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        if self.api_client.client_side_validation and 'page_size' in local_var_params and local_var_params['page_size'] > 10000:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_size` when calling `list_files`, must be a value less than or equal to `10000`")  # noqa: E501
        if self.api_client.client_side_validation and 'page_size' in local_var_params and local_var_params['page_size'] < 0:  # noqa: E501
            raise ApiValueError("Invalid value for parameter `page_size` when calling `list_files`, must be a value greater than or equal to `0`")  # noqa: E501
        collection_formats = {}

        path_params = {}

        query_params = []
        if 'volume_id' in local_var_params and local_var_params['volume_id'] is not None:  # noqa: E501
            query_params.append(('volume.id', local_var_params['volume_id']))  # noqa: E501
            collection_formats['volume.id'] = 'csv'  # noqa: E501
        if 'volume_name' in local_var_params and local_var_params['volume_name'] is not None:  # noqa: E501
            query_params.append(('volume.name', local_var_params['volume_name']))  # noqa: E501
            collection_formats['volume.name'] = 'csv'  # noqa: E501
        if 'path' in local_var_params and local_var_params['path'] is not None:  # noqa: E501
            query_params.append(('path', local_var_params['path']))  # noqa: E501
            collection_formats['path'] = 'csv'  # noqa: E501
        if 'is_uploaded' in local_var_params and local_var_params['is_uploaded'] is not None:  # noqa: E501
            query_params.append(('isUploaded', local_var_params['is_uploaded']))  # noqa: E501
        if 'archive_status' in local_var_params and local_var_params['archive_status'] is not None:  # noqa: E501
            query_params.append(('archiveStatus', local_var_params['archive_status']))  # noqa: E501
        if 'recursive' in local_var_params and local_var_params['recursive'] is not None:  # noqa: E501
            query_params.append(('recursive', local_var_params['recursive']))  # noqa: E501
        if 'page_size' in local_var_params and local_var_params['page_size'] is not None:  # noqa: E501
            query_params.append(('pageSize', local_var_params['page_size']))  # noqa: E501
        if 'page_token' in local_var_params and local_var_params['page_token'] is not None:  # noqa: E501
            query_params.append(('pageToken', local_var_params['page_token']))  # noqa: E501
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501
        if 'tenant_id' in local_var_params and local_var_params['tenant_id'] is not None:  # noqa: E501
            query_params.append(('tenantId', local_var_params['tenant_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileListResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def unarchive_file(self, file_id, body, **kwargs):  # noqa: E501
        """Unarchive a file  # noqa: E501

        Unarchive a file from a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unarchive_file(file_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to be unarchived. (required)
        :param FileUnarchiveRequest body: (required)
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.unarchive_file_with_http_info(file_id, body, **kwargs)  # noqa: E501

    def unarchive_file_with_http_info(self, file_id, body, **kwargs):  # noqa: E501
        """Unarchive a file  # noqa: E501

        Unarchive a file from a lower storage cost tier.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.unarchive_file_with_http_info(file_id, body, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to be unarchived. (required)
        :param FileUnarchiveRequest body: (required)
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method unarchive_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `unarchive_file`")  # noqa: E501
        # verify the required parameter 'body' is set
        if self.api_client.client_side_validation and ('body' not in local_var_params or  # noqa: E501
                                                        local_var_params['body'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `body` when calling `unarchive_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json-patch+json', 'application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{fileId}:unarchive', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def update_file(self, file_id, **kwargs):  # noqa: E501
        """Update a file entry in GDS and get temporary credentials for upload  # noqa: E501

        Update a file entry in GDS. Returns temporary credentials for file upload directly to S3 when the include=objectStoreAccess parameter is used. Note that the currently supported changes to the file resource are updating the file type and the underlying content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_file(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to be updated. (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param UpdateFileRequest body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: FileWriteableResponse
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.update_file_with_http_info(file_id, **kwargs)  # noqa: E501

    def update_file_with_http_info(self, file_id, **kwargs):  # noqa: E501
        """Update a file entry in GDS and get temporary credentials for upload  # noqa: E501

        Update a file entry in GDS. Returns temporary credentials for file upload directly to S3 when the include=objectStoreAccess parameter is used. Note that the currently supported changes to the file resource are updating the file type and the underlying content.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.update_file_with_http_info(file_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str file_id: Unique identifier for the file to be updated. (required)
        :param str include: Comma-separated list of properties to include in the response ([include=[totalItemCount]).Example: include=totalItemCount
        :param UpdateFileRequest body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(FileWriteableResponse, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'file_id',
            'include',
            'body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method update_file" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']
        # verify the required parameter 'file_id' is set
        if self.api_client.client_side_validation and ('file_id' not in local_var_params or  # noqa: E501
                                                        local_var_params['file_id'] is None):  # noqa: E501
            raise ApiValueError("Missing the required parameter `file_id` when calling `update_file`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'file_id' in local_var_params:
            path_params['fileId'] = local_var_params['file_id']  # noqa: E501

        query_params = []
        if 'include' in local_var_params and local_var_params['include'] is not None:  # noqa: E501
            query_params.append(('include', local_var_params['include']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in local_var_params:
            body_params = local_var_params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = ['Bearer']  # noqa: E501

        return self.api_client.call_api(
            '/v1/files/{fileId}', 'PATCH',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='FileWriteableResponse',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libtes
from libica.openapi.libtes.api.task_runs_api import TaskRunsApi  # noqa: E501
from libica.openapi.libtes.rest import ApiException


class TestTaskRunsApi(unittest.TestCase):
    """TaskRunsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libtes.api.task_runs_api.TaskRunsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_abort_task_run(self):
        """Test case for abort_task_run

        Abort a task run  # noqa: E501
        """
        pass

    def test_create_task_run(self):
        """Test case for create_task_run

        Create and launch a task run  # noqa: E501
        """
        pass

    def test_get_task_run(self):
        """Test case for get_task_run

        Get the status of a task run  # noqa: E501
        """
        pass

    def test_list_task_runs(self):
        """Test case for list_task_runs

        Get a list of task runs  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libgds
from libica.openapi.libgds.api.volume_configurations_api import VolumeConfigurationsApi  # noqa: E501
from libica.openapi.libgds.rest import ApiException


class TestVolumeConfigurationsApi(unittest.TestCase):
    """VolumeConfigurationsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libgds.api.volume_configurations_api.VolumeConfigurationsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_volume_configuration(self):
        """Test case for create_volume_configuration

        Create a volume configuration in GDS.  # noqa: E501
        """
        pass

    def test_delete_volume_configuration(self):
        """Test case for delete_volume_configuration

        Deletes a volume configuration by Id or name  # noqa: E501
        """
        pass

    def test_get_volume_configuration(self):
        """Test case for get_volume_configuration

        Get information for the specified volume configuration name or Id  # noqa: E501
        """
        pass

    def test_list_volume_configurations(self):
        """Test case for list_volume_configurations

        Get a list of volumes  # noqa: E501
        """
        pass

    def test_validate_volume_configuration(self):
        """Test case for validate_volume_configuration

        Validate a volume configuration  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libwes.configuration import Configuration


class WorkflowRun(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'urn': 'str',
        'href': 'str',
        'name': 'str',
        'time_started': 'datetime',
        'time_stopped': 'datetime',
        'status': 'str',
        'idempotency_key': 'str',
        'status_summary': 'str',
        'error': 'str',
        'error_cause': 'str',
        'workflow_version': 'WorkflowVersionCompact',
        'created_by_client_id': 'str',
        'input': 'object',
        'output': 'object',
        'definition': 'str',
        'engine_parameters': 'str',
        'time_created': 'datetime',
        'time_modified': 'datetime',
        'created_by': 'str',
        'modified_by': 'str',
        'tenant_id': 'str',
        'acl': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'urn': 'urn',
        'href': 'href',
        'name': 'name',
        'time_started': 'timeStarted',
        'time_stopped': 'timeStopped',
        'status': 'status',
        'idempotency_key': 'idempotencyKey',
        'status_summary': 'statusSummary',
        'error': 'error',
        'error_cause': 'errorCause',
        'workflow_version': 'workflowVersion',
        'created_by_client_id': 'createdByClientId',
        'input': 'input',
        'output': 'output',
        'definition': 'definition',
        'engine_parameters': 'engineParameters',
        'time_created': 'timeCreated',
        'time_modified': 'timeModified',
        'created_by': 'createdBy',
        'modified_by': 'modifiedBy',
        'tenant_id': 'tenantId',
        'acl': 'acl'
    }

    def __init__(self, id=None, urn=None, href=None, name=None, time_started=None, time_stopped=None, status=None, idempotency_key=None, status_summary=None, error=None, error_cause=None, workflow_version=None, created_by_client_id=None, input=None, output=None, definition=None, engine_parameters=None, time_created=None, time_modified=None, created_by=None, modified_by=None, tenant_id=None, acl=None, local_vars_configuration=None):  # noqa: E501
        """WorkflowRun - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._urn = None
        self._href = None
        self._name = None
        self._time_started = None
        self._time_stopped = None
        self._status = None
        self._idempotency_key = None
        self._status_summary = None
        self._error = None
        self._error_cause = None
        self._workflow_version = None
        self._created_by_client_id = None
        self._input = None
        self._output = None
        self._definition = None
        self._engine_parameters = None
        self._time_created = None
        self._time_modified = None
        self._created_by = None
        self._modified_by = None
        self._tenant_id = None
        self._acl = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if urn is not None:
            self.urn = urn
        if href is not None:
            self.href = href
        if name is not None:
            self.name = name
        if time_started is not None:
            self.time_started = time_started
        if time_stopped is not None:
            self.time_stopped = time_stopped
        if status is not None:
            self.status = status
        if idempotency_key is not None:
            self.idempotency_key = idempotency_key
        if status_summary is not None:
            self.status_summary = status_summary
        if error is not None:
            self.error = error
        if error_cause is not None:
            self.error_cause = error_cause
        if workflow_version is not None:
            self.workflow_version = workflow_version
        if created_by_client_id is not None:
            self.created_by_client_id = created_by_client_id
        if input is not None:
            self.input = input
        if output is not None:
            self.output = output
        if definition is not None:
            self.definition = definition
        if engine_parameters is not None:
            self.engine_parameters = engine_parameters
        if time_created is not None:
            self.time_created = time_created
        if time_modified is not None:
            self.time_modified = time_modified
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if acl is not None:
            self.acl = acl

    @property
    def id(self):
        """Gets the id of this WorkflowRun.  # noqa: E501

        Unique resource ID  # noqa: E501

        :return: The id of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WorkflowRun.

        Unique resource ID  # noqa: E501

        :param id: The id of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def urn(self):
        """Gets the urn of this WorkflowRun.  # noqa: E501

        URN of the resource  # noqa: E501

        :return: The urn of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this WorkflowRun.

        URN of the resource  # noqa: E501

        :param urn: The urn of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def href(self):
        """Gets the href of this WorkflowRun.  # noqa: E501

        HREF to the resource  # noqa: E501

        :return: The href of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this WorkflowRun.

        HREF to the resource  # noqa: E501

        :param href: The href of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def name(self):
        """Gets the name of this WorkflowRun.  # noqa: E501

        Name of the workflow run  # noqa: E501

        :return: The name of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this WorkflowRun.

        Name of the workflow run  # noqa: E501

        :param name: The name of this WorkflowRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) > 255):
            raise ValueError("Invalid value for `name`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                name is not None and len(name) < 0):
            raise ValueError("Invalid value for `name`, length must be greater than or equal to `0`")  # noqa: E501

        self._name = name

    @property
    def time_started(self):
        """Gets the time_started of this WorkflowRun.  # noqa: E501

        The time (in UTC) the workflow run started  # noqa: E501

        :return: The time_started of this WorkflowRun.  # noqa: E501
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """Sets the time_started of this WorkflowRun.

        The time (in UTC) the workflow run started  # noqa: E501

        :param time_started: The time_started of this WorkflowRun.  # noqa: E501
        :type: datetime
        """

        self._time_started = time_started

    @property
    def time_stopped(self):
        """Gets the time_stopped of this WorkflowRun.  # noqa: E501

        The time (in UTC) the Workflow Run stopped  # noqa: E501

        :return: The time_stopped of this WorkflowRun.  # noqa: E501
        :rtype: datetime
        """
        return self._time_stopped

    @time_stopped.setter
    def time_stopped(self, time_stopped):
        """Sets the time_stopped of this WorkflowRun.

        The time (in UTC) the Workflow Run stopped  # noqa: E501

        :param time_stopped: The time_stopped of this WorkflowRun.  # noqa: E501
        :type: datetime
        """

        self._time_stopped = time_stopped

    @property
    def status(self):
        """Gets the status of this WorkflowRun.  # noqa: E501

        Workflow run status  # noqa: E501

        :return: The status of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WorkflowRun.

        Workflow run status  # noqa: E501

        :param status: The status of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def idempotency_key(self):
        """Gets the idempotency_key of this WorkflowRun.  # noqa: E501


        :return: The idempotency_key of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._idempotency_key

    @idempotency_key.setter
    def idempotency_key(self, idempotency_key):
        """Sets the idempotency_key of this WorkflowRun.


        :param idempotency_key: The idempotency_key of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._idempotency_key = idempotency_key

    @property
    def status_summary(self):
        """Gets the status_summary of this WorkflowRun.  # noqa: E501

        Workflow run status summary  # noqa: E501

        :return: The status_summary of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._status_summary

    @status_summary.setter
    def status_summary(self, status_summary):
        """Sets the status_summary of this WorkflowRun.

        Workflow run status summary  # noqa: E501

        :param status_summary: The status_summary of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._status_summary = status_summary

    @property
    def error(self):
        """Gets the error of this WorkflowRun.  # noqa: E501

        Error for a failed workflow run  # noqa: E501

        :return: The error of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._error

    @error.setter
    def error(self, error):
        """Sets the error of this WorkflowRun.

        Error for a failed workflow run  # noqa: E501

        :param error: The error of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._error = error

    @property
    def error_cause(self):
        """Gets the error_cause of this WorkflowRun.  # noqa: E501

        Error cause for a failed workflow run  # noqa: E501

        :return: The error_cause of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._error_cause

    @error_cause.setter
    def error_cause(self, error_cause):
        """Sets the error_cause of this WorkflowRun.

        Error cause for a failed workflow run  # noqa: E501

        :param error_cause: The error_cause of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._error_cause = error_cause

    @property
    def workflow_version(self):
        """Gets the workflow_version of this WorkflowRun.  # noqa: E501


        :return: The workflow_version of this WorkflowRun.  # noqa: E501
        :rtype: WorkflowVersionCompact
        """
        return self._workflow_version

    @workflow_version.setter
    def workflow_version(self, workflow_version):
        """Sets the workflow_version of this WorkflowRun.


        :param workflow_version: The workflow_version of this WorkflowRun.  # noqa: E501
        :type: WorkflowVersionCompact
        """

        self._workflow_version = workflow_version

    @property
    def created_by_client_id(self):
        """Gets the created_by_client_id of this WorkflowRun.  # noqa: E501

        Client ID of the Origin Request  # noqa: E501

        :return: The created_by_client_id of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._created_by_client_id

    @created_by_client_id.setter
    def created_by_client_id(self, created_by_client_id):
        """Sets the created_by_client_id of this WorkflowRun.

        Client ID of the Origin Request  # noqa: E501

        :param created_by_client_id: The created_by_client_id of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._created_by_client_id = created_by_client_id

    @property
    def input(self):
        """Gets the input of this WorkflowRun.  # noqa: E501

        Input to workflow run, as JSON  # noqa: E501

        :return: The input of this WorkflowRun.  # noqa: E501
        :rtype: object
        """
        return self._input

    @input.setter
    def input(self, input):
        """Sets the input of this WorkflowRun.

        Input to workflow run, as JSON  # noqa: E501

        :param input: The input of this WorkflowRun.  # noqa: E501
        :type: object
        """

        self._input = input

    @property
    def output(self):
        """Gets the output of this WorkflowRun.  # noqa: E501

        Output from workflow run, as JSON  # noqa: E501

        :return: The output of this WorkflowRun.  # noqa: E501
        :rtype: object
        """
        return self._output

    @output.setter
    def output(self, output):
        """Sets the output of this WorkflowRun.

        Output from workflow run, as JSON  # noqa: E501

        :param output: The output of this WorkflowRun.  # noqa: E501
        :type: object
        """

        self._output = output

    @property
    def definition(self):
        """Gets the definition of this WorkflowRun.  # noqa: E501

        Definition of the workflow version  # noqa: E501

        :return: The definition of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._definition

    @definition.setter
    def definition(self, definition):
        """Sets the definition of this WorkflowRun.

        Definition of the workflow version  # noqa: E501

        :param definition: The definition of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._definition = definition

    @property
    def engine_parameters(self):
        """Gets the engine_parameters of this WorkflowRun.  # noqa: E501

        Workflow Engine Parameters  # noqa: E501

        :return: The engine_parameters of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._engine_parameters

    @engine_parameters.setter
    def engine_parameters(self, engine_parameters):
        """Sets the engine_parameters of this WorkflowRun.

        Workflow Engine Parameters  # noqa: E501

        :param engine_parameters: The engine_parameters of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._engine_parameters = engine_parameters

    @property
    def time_created(self):
        """Gets the time_created of this WorkflowRun.  # noqa: E501

        Time (in UTC) the resource was created  # noqa: E501

        :return: The time_created of this WorkflowRun.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this WorkflowRun.

        Time (in UTC) the resource was created  # noqa: E501

        :param time_created: The time_created of this WorkflowRun.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def time_modified(self):
        """Gets the time_modified of this WorkflowRun.  # noqa: E501

        Time (in UTC) the resource was modified  # noqa: E501

        :return: The time_modified of this WorkflowRun.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this WorkflowRun.

        Time (in UTC) the resource was modified  # noqa: E501

        :param time_modified: The time_modified of this WorkflowRun.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def created_by(self):
        """Gets the created_by of this WorkflowRun.  # noqa: E501

        User that created the resource  # noqa: E501

        :return: The created_by of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this WorkflowRun.

        User that created the resource  # noqa: E501

        :param created_by: The created_by of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this WorkflowRun.  # noqa: E501

        User that modified the resource  # noqa: E501

        :return: The modified_by of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this WorkflowRun.

        User that modified the resource  # noqa: E501

        :param modified_by: The modified_by of this WorkflowRun.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def tenant_id(self):
        """Gets the tenant_id of this WorkflowRun.  # noqa: E501

        Tenant ID the resource belongs to  # noqa: E501

        :return: The tenant_id of this WorkflowRun.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this WorkflowRun.

        Tenant ID the resource belongs to  # noqa: E501

        :param tenant_id: The tenant_id of this WorkflowRun.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                tenant_id is not None and len(tenant_id) > 255):
            raise ValueError("Invalid value for `tenant_id`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                tenant_id is not None and len(tenant_id) < 0):
            raise ValueError("Invalid value for `tenant_id`, length must be greater than or equal to `0`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def acl(self):
        """Gets the acl of this WorkflowRun.  # noqa: E501

        Access control list of the resource  # noqa: E501

        :return: The acl of this WorkflowRun.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this WorkflowRun.

        Access control list of the resource  # noqa: E501

        :param acl: The acl of this WorkflowRun.  # noqa: E501
        :type: list[str]
        """

        self._acl = acl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowRun):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowRun):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libgds
from libica.openapi.libgds.models.volume_configuration_list_response import VolumeConfigurationListResponse  # noqa: E501
from libica.openapi.libgds.rest import ApiException

class TestVolumeConfigurationListResponse(unittest.TestCase):
    """VolumeConfigurationListResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VolumeConfigurationListResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libgds.models.volume_configuration_list_response.VolumeConfigurationListResponse()  # noqa: E501
        if include_optional :
            return VolumeConfigurationListResponse(
                items = [
                    libica.openapi.libgds.models.volume_configuration_response.VolumeConfigurationResponse(
                        name = '0', 
                        tenant_id = '0', 
                        sub_tenant_id = '0', 
                        urn = '0', 
                        online_status = 'Initializing', 
                        error_code = '0', 
                        error_message = '0', 
                        time_of_last_error = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = '0', 
                        time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified_by = '0', 
                        object_store_settings = libica.openapi.libgds.models.object_store_settings.ObjectStoreSettings(
                            aws_s3 = libica.openapi.libgds.models.awss3_object_store_setting.AWSS3ObjectStoreSetting(
                                bucket_name = '012', 
                                key_prefix = 'gds-volumes/', ), 
                            # platform_credentials_name = '0',
                            secret_name='test',
                        ), )
                    ],
                item_count = 56, 
                first_page_token = '0', 
                next_page_token = '0', 
                prev_page_token = '0', 
                last_page_token = '0', 
                total_item_count = 56, 
                total_page_count = 56
            )
        else :
            return VolumeConfigurationListResponse(
        )

    def testVolumeConfigurationListResponse(self):
        """Test VolumeConfigurationListResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libconsole
from libica.openapi.libconsole.models.account_response import AccountResponse  # noqa: E501
from libica.openapi.libconsole.rest import ApiException

class TestAccountResponse(unittest.TestCase):
    """AccountResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test AccountResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libconsole.models.account_response.AccountResponse()  # noqa: E501
        if include_optional :
            return AccountResponse(
                id = '0', 
                type = '0', 
                name = '0', 
                domain = libica.openapi.libconsole.models.domain.Domain(
                    id = '0', 
                    name = '0', )
            )
        else :
            return AccountResponse(
        )

    def testAccountResponse(self):
        """Test AccountResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.heartbeat_task_run_request import HeartbeatTaskRunRequest  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestHeartbeatTaskRunRequest(unittest.TestCase):
    """HeartbeatTaskRunRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test HeartbeatTaskRunRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.heartbeat_task_run_request.HeartbeatTaskRunRequest()  # noqa: E501
        if include_optional :
            return HeartbeatTaskRunRequest(
                last_heartbeat = True, 
                pod_name = '0', 
                pod_uid = '0', 
                pod_hardware_details = '0', 
                job_retry_count = 56, 
                nonce = '0', 
                container_status = [
                    libica.openapi.libtes.models.container_status.ContainerStatus(
                        name = '0', 
                        state = libica.openapi.libtes.models.container_state.ContainerState(
                            waiting = libica.openapi.libtes.models.container_state_waiting.ContainerStateWaiting(
                                reason = '0', 
                                message = '0', ), 
                            running = libica.openapi.libtes.models.container_state_running.ContainerStateRunning(
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                            terminated = libica.openapi.libtes.models.container_state_terminated.ContainerStateTerminated(
                                exit_code = 56, 
                                signal = 56, 
                                reason = '0', 
                                message = '0', 
                                started_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                finished_at = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                container_id = '0', ), ), )
                    ]
            )
        else :
            return HeartbeatTaskRunRequest(
        )

    def testHeartbeatTaskRunRequest(self):
        """Test HeartbeatTaskRunRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libwes.configuration import Configuration


class WorkflowVersionCompact(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'urn': 'str',
        'href': 'str',
        'version': 'str',
        'category': 'str',
        'description': 'str',
        'language': 'WorkflowLanguage',
        'status': 'str',
        'created_by_client_id': 'str',
        'time_created': 'datetime',
        'time_modified': 'datetime',
        'created_by': 'str',
        'modified_by': 'str',
        'tenant_id': 'str',
        'acl': 'list[str]'
    }

    attribute_map = {
        'id': 'id',
        'urn': 'urn',
        'href': 'href',
        'version': 'version',
        'category': 'category',
        'description': 'description',
        'language': 'language',
        'status': 'status',
        'created_by_client_id': 'createdByClientId',
        'time_created': 'timeCreated',
        'time_modified': 'timeModified',
        'created_by': 'createdBy',
        'modified_by': 'modifiedBy',
        'tenant_id': 'tenantId',
        'acl': 'acl'
    }

    def __init__(self, id=None, urn=None, href=None, version=None, category=None, description=None, language=None, status=None, created_by_client_id=None, time_created=None, time_modified=None, created_by=None, modified_by=None, tenant_id=None, acl=None, local_vars_configuration=None):  # noqa: E501
        """WorkflowVersionCompact - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._urn = None
        self._href = None
        self._version = None
        self._category = None
        self._description = None
        self._language = None
        self._status = None
        self._created_by_client_id = None
        self._time_created = None
        self._time_modified = None
        self._created_by = None
        self._modified_by = None
        self._tenant_id = None
        self._acl = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if urn is not None:
            self.urn = urn
        if href is not None:
            self.href = href
        if version is not None:
            self.version = version
        if category is not None:
            self.category = category
        if description is not None:
            self.description = description
        if language is not None:
            self.language = language
        if status is not None:
            self.status = status
        if created_by_client_id is not None:
            self.created_by_client_id = created_by_client_id
        if time_created is not None:
            self.time_created = time_created
        if time_modified is not None:
            self.time_modified = time_modified
        if created_by is not None:
            self.created_by = created_by
        if modified_by is not None:
            self.modified_by = modified_by
        if tenant_id is not None:
            self.tenant_id = tenant_id
        if acl is not None:
            self.acl = acl

    @property
    def id(self):
        """Gets the id of this WorkflowVersionCompact.  # noqa: E501

        Unique resource ID  # noqa: E501

        :return: The id of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this WorkflowVersionCompact.

        Unique resource ID  # noqa: E501

        :param id: The id of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def urn(self):
        """Gets the urn of this WorkflowVersionCompact.  # noqa: E501

        URN of the resource  # noqa: E501

        :return: The urn of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this WorkflowVersionCompact.

        URN of the resource  # noqa: E501

        :param urn: The urn of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def href(self):
        """Gets the href of this WorkflowVersionCompact.  # noqa: E501

        HREF to the resource  # noqa: E501

        :return: The href of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._href

    @href.setter
    def href(self, href):
        """Sets the href of this WorkflowVersionCompact.

        HREF to the resource  # noqa: E501

        :param href: The href of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """

        self._href = href

    @property
    def version(self):
        """Gets the version of this WorkflowVersionCompact.  # noqa: E501

        Name of the workflow version  # noqa: E501

        :return: The version of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this WorkflowVersionCompact.

        Name of the workflow version  # noqa: E501

        :param version: The version of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                version is not None and len(version) > 40):
            raise ValueError("Invalid value for `version`, length must be less than or equal to `40`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                version is not None and len(version) < 0):
            raise ValueError("Invalid value for `version`, length must be greater than or equal to `0`")  # noqa: E501

        self._version = version

    @property
    def category(self):
        """Gets the category of this WorkflowVersionCompact.  # noqa: E501

        Category of the workflow version  # noqa: E501

        :return: The category of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._category

    @category.setter
    def category(self, category):
        """Sets the category of this WorkflowVersionCompact.

        Category of the workflow version  # noqa: E501

        :param category: The category of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                category is not None and len(category) > 128):
            raise ValueError("Invalid value for `category`, length must be less than or equal to `128`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                category is not None and len(category) < 0):
            raise ValueError("Invalid value for `category`, length must be greater than or equal to `0`")  # noqa: E501

        self._category = category

    @property
    def description(self):
        """Gets the description of this WorkflowVersionCompact.  # noqa: E501

        Description of the workflow version  # noqa: E501

        :return: The description of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this WorkflowVersionCompact.

        Description of the workflow version  # noqa: E501

        :param description: The description of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) > 256):
            raise ValueError("Invalid value for `description`, length must be less than or equal to `256`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                description is not None and len(description) < 0):
            raise ValueError("Invalid value for `description`, length must be greater than or equal to `0`")  # noqa: E501

        self._description = description

    @property
    def language(self):
        """Gets the language of this WorkflowVersionCompact.  # noqa: E501


        :return: The language of this WorkflowVersionCompact.  # noqa: E501
        :rtype: WorkflowLanguage
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this WorkflowVersionCompact.


        :param language: The language of this WorkflowVersionCompact.  # noqa: E501
        :type: WorkflowLanguage
        """

        self._language = language

    @property
    def status(self):
        """Gets the status of this WorkflowVersionCompact.  # noqa: E501

        Published Status of the workflow version  # noqa: E501

        :return: The status of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this WorkflowVersionCompact.

        Published Status of the workflow version  # noqa: E501

        :param status: The status of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """

        self._status = status

    @property
    def created_by_client_id(self):
        """Gets the created_by_client_id of this WorkflowVersionCompact.  # noqa: E501

        Client ID of the Origin Request  # noqa: E501

        :return: The created_by_client_id of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._created_by_client_id

    @created_by_client_id.setter
    def created_by_client_id(self, created_by_client_id):
        """Sets the created_by_client_id of this WorkflowVersionCompact.

        Client ID of the Origin Request  # noqa: E501

        :param created_by_client_id: The created_by_client_id of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """

        self._created_by_client_id = created_by_client_id

    @property
    def time_created(self):
        """Gets the time_created of this WorkflowVersionCompact.  # noqa: E501

        Time (in UTC) the resource was created  # noqa: E501

        :return: The time_created of this WorkflowVersionCompact.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this WorkflowVersionCompact.

        Time (in UTC) the resource was created  # noqa: E501

        :param time_created: The time_created of this WorkflowVersionCompact.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def time_modified(self):
        """Gets the time_modified of this WorkflowVersionCompact.  # noqa: E501

        Time (in UTC) the resource was modified  # noqa: E501

        :return: The time_modified of this WorkflowVersionCompact.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this WorkflowVersionCompact.

        Time (in UTC) the resource was modified  # noqa: E501

        :param time_modified: The time_modified of this WorkflowVersionCompact.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    @property
    def created_by(self):
        """Gets the created_by of this WorkflowVersionCompact.  # noqa: E501

        User that created the resource  # noqa: E501

        :return: The created_by of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this WorkflowVersionCompact.

        User that created the resource  # noqa: E501

        :param created_by: The created_by of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """

        self._created_by = created_by

    @property
    def modified_by(self):
        """Gets the modified_by of this WorkflowVersionCompact.  # noqa: E501

        User that modified the resource  # noqa: E501

        :return: The modified_by of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._modified_by

    @modified_by.setter
    def modified_by(self, modified_by):
        """Sets the modified_by of this WorkflowVersionCompact.

        User that modified the resource  # noqa: E501

        :param modified_by: The modified_by of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """

        self._modified_by = modified_by

    @property
    def tenant_id(self):
        """Gets the tenant_id of this WorkflowVersionCompact.  # noqa: E501

        Tenant ID the resource belongs to  # noqa: E501

        :return: The tenant_id of this WorkflowVersionCompact.  # noqa: E501
        :rtype: str
        """
        return self._tenant_id

    @tenant_id.setter
    def tenant_id(self, tenant_id):
        """Sets the tenant_id of this WorkflowVersionCompact.

        Tenant ID the resource belongs to  # noqa: E501

        :param tenant_id: The tenant_id of this WorkflowVersionCompact.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                tenant_id is not None and len(tenant_id) > 255):
            raise ValueError("Invalid value for `tenant_id`, length must be less than or equal to `255`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                tenant_id is not None and len(tenant_id) < 0):
            raise ValueError("Invalid value for `tenant_id`, length must be greater than or equal to `0`")  # noqa: E501

        self._tenant_id = tenant_id

    @property
    def acl(self):
        """Gets the acl of this WorkflowVersionCompact.  # noqa: E501

        Access control list of the resource  # noqa: E501

        :return: The acl of this WorkflowVersionCompact.  # noqa: E501
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """Sets the acl of this WorkflowVersionCompact.

        Access control list of the resource  # noqa: E501

        :param acl: The acl of this WorkflowVersionCompact.  # noqa: E501
        :type: list[str]
        """

        self._acl = acl

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, WorkflowVersionCompact):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, WorkflowVersionCompact):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.create_task_version_request import CreateTaskVersionRequest  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestCreateTaskVersionRequest(unittest.TestCase):
    """CreateTaskVersionRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateTaskVersionRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.create_task_version_request.CreateTaskVersionRequest()  # noqa: E501
        if include_optional :
            return CreateTaskVersionRequest(
                version = '0', 
                description = '0', 
                execution = libica.openapi.libtes.models.execution.Execution(
                    image = libica.openapi.libtes.models.image.Image(
                        name = '0', 
                        tag = '0', 
                        digest = '0', 
                        credentials = libica.openapi.libtes.models.credentials.Credentials(
                            username = '0', 
                            password = '0', ), ), 
                    command = '0', 
                    args = [
                        '0'
                        ], 
                    inputs = [
                        libica.openapi.libtes.models.input_mount_mapping_with_creds.InputMountMappingWithCreds(
                            storage_provider = '0', 
                            path = '0', 
                            url = '0', 
                            urn = '0', 
                            mode = '0', 
                            type = 'File', )
                        ], 
                    outputs = [
                        libica.openapi.libtes.models.mount_mapping_with_creds.MountMappingWithCreds(
                            path = '0', 
                            url = '0', 
                            urn = '0', 
                            type = '0', 
                            storage_provider = '0', )
                        ], 
                    system_files = libica.openapi.libtes.models.system_files.SystemFiles(
                        url = '0', 
                        urn = '0', 
                        storage_provider = '0', ), 
                    environment = libica.openapi.libtes.models.environment.Environment(
                        variables = {
                            'key' : '0'
                            }, 
                        resources = libica.openapi.libtes.models.resources.Resources(
                            type = '0', 
                            size = '0', 
                            cpu_cores = 1.337, 
                            memory_gb = 1.337, 
                            hardware = [
                                '0'
                                ], 
                            tier = '0', ), 
                        input_stream_settings = libica.openapi.libtes.models.input_stream_settings.InputStreamSettings(
                            access_pattern = 'sequential', 
                            cache_size_gb = 5E+1, 
                            block_size_mb = 0, 
                            prefetch_blocks = 0, ), ), 
                    working_directory = '0', 
                    retry_limit = 56, 
                    retry_count = 56, ), 
                acl = [
                    '0'
                    ]
            )
        else :
            return CreateTaskVersionRequest(
                version = '0',
        )

    def testCreateTaskVersionRequest(self):
        """Test CreateTaskVersionRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libconsole.configuration import Configuration


class Project(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'id': 'str',
        'urn': 'str',
        'name': 'str',
        'owner': 'str',
        'time_created': 'datetime',
        'time_modified': 'datetime'
    }

    attribute_map = {
        'id': 'id',
        'urn': 'urn',
        'name': 'name',
        'owner': 'owner',
        'time_created': 'timeCreated',
        'time_modified': 'timeModified'
    }

    def __init__(self, id=None, urn=None, name=None, owner=None, time_created=None, time_modified=None, local_vars_configuration=None):  # noqa: E501
        """Project - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._id = None
        self._urn = None
        self._name = None
        self._owner = None
        self._time_created = None
        self._time_modified = None
        self.discriminator = None

        if id is not None:
            self.id = id
        if urn is not None:
            self.urn = urn
        if name is not None:
            self.name = name
        if owner is not None:
            self.owner = owner
        if time_created is not None:
            self.time_created = time_created
        if time_modified is not None:
            self.time_modified = time_modified

    @property
    def id(self):
        """Gets the id of this Project.  # noqa: E501


        :return: The id of this Project.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this Project.


        :param id: The id of this Project.  # noqa: E501
        :type: str
        """

        self._id = id

    @property
    def urn(self):
        """Gets the urn of this Project.  # noqa: E501


        :return: The urn of this Project.  # noqa: E501
        :rtype: str
        """
        return self._urn

    @urn.setter
    def urn(self, urn):
        """Sets the urn of this Project.


        :param urn: The urn of this Project.  # noqa: E501
        :type: str
        """

        self._urn = urn

    @property
    def name(self):
        """Gets the name of this Project.  # noqa: E501


        :return: The name of this Project.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this Project.


        :param name: The name of this Project.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def owner(self):
        """Gets the owner of this Project.  # noqa: E501


        :return: The owner of this Project.  # noqa: E501
        :rtype: str
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """Sets the owner of this Project.


        :param owner: The owner of this Project.  # noqa: E501
        :type: str
        """

        self._owner = owner

    @property
    def time_created(self):
        """Gets the time_created of this Project.  # noqa: E501


        :return: The time_created of this Project.  # noqa: E501
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """Sets the time_created of this Project.


        :param time_created: The time_created of this Project.  # noqa: E501
        :type: datetime
        """

        self._time_created = time_created

    @property
    def time_modified(self):
        """Gets the time_modified of this Project.  # noqa: E501


        :return: The time_modified of this Project.  # noqa: E501
        :rtype: datetime
        """
        return self._time_modified

    @time_modified.setter
    def time_modified(self, time_modified):
        """Sets the time_modified of this Project.


        :param time_modified: The time_modified of this Project.  # noqa: E501
        :type: datetime
        """

        self._time_modified = time_modified

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, Project):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, Project):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.task_run_logs import TaskRunLogs  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestTaskRunLogs(unittest.TestCase):
    """TaskRunLogs unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TaskRunLogs
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.task_run_logs.TaskRunLogs()  # noqa: E501
        if include_optional :
            return TaskRunLogs(
                start_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                end_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                error = '0', 
                error_details = '0', 
                stdout = '0', 
                stderr = '0'
            )
        else :
            return TaskRunLogs(
        )

    def testTaskRunLogs(self):
        """Test TaskRunLogs"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.create_task_request import CreateTaskRequest  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestCreateTaskRequest(unittest.TestCase):
    """CreateTaskRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test CreateTaskRequest
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.create_task_request.CreateTaskRequest()  # noqa: E501
        if include_optional :
            return CreateTaskRequest(
                name = '0', 
                description = '0', 
                acl = [
                    '0'
                    ], 
                task_versions = [
                    libica.openapi.libtes.models.create_task_version_request.CreateTaskVersionRequest(
                        version = '0', 
                        description = '0', 
                        execution = libica.openapi.libtes.models.execution.Execution(
                            image = libica.openapi.libtes.models.image.Image(
                                name = '0', 
                                tag = '0', 
                                digest = '0', 
                                credentials = libica.openapi.libtes.models.credentials.Credentials(
                                    username = '0', 
                                    password = '0', ), ), 
                            command = '0', 
                            args = [
                                '0'
                                ], 
                            inputs = [
                                libica.openapi.libtes.models.input_mount_mapping_with_creds.InputMountMappingWithCreds(
                                    storage_provider = '0', 
                                    path = '0', 
                                    url = '0', 
                                    urn = '0', 
                                    mode = '0', 
                                    type = 'File', )
                                ], 
                            outputs = [
                                libica.openapi.libtes.models.mount_mapping_with_creds.MountMappingWithCreds(
                                    path = '0', 
                                    url = '0', 
                                    urn = '0', 
                                    type = '0', 
                                    storage_provider = '0', )
                                ], 
                            system_files = libica.openapi.libtes.models.system_files.SystemFiles(
                                url = '0', 
                                urn = '0', 
                                storage_provider = '0', ), 
                            environment = libica.openapi.libtes.models.environment.Environment(
                                variables = {
                                    'key' : '0'
                                    }, 
                                resources = libica.openapi.libtes.models.resources.Resources(
                                    type = '0', 
                                    size = '0', 
                                    cpu_cores = 1.337, 
                                    memory_gb = 1.337, 
                                    hardware = [
                                        '0'
                                        ], 
                                    tier = '0', ), 
                                input_stream_settings = libica.openapi.libtes.models.input_stream_settings.InputStreamSettings(
                                    access_pattern = 'sequential', 
                                    cache_size_gb = 5E+1, 
                                    block_size_mb = 0, 
                                    prefetch_blocks = 0, ), ), 
                            working_directory = '0', 
                            retry_limit = 56, 
                            retry_count = 56, ), 
                        acl = [
                            '0'
                            ], )
                    ]
            )
        else :
            return CreateTaskRequest(
                name = '0',
        )

    def testCreateTaskRequest(self):
        """Test CreateTaskRequest"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libgds
from libica.openapi.libgds.models.volume_configuration_response import VolumeConfigurationResponse  # noqa: E501
from libica.openapi.libgds.rest import ApiException

class TestVolumeConfigurationResponse(unittest.TestCase):
    """VolumeConfigurationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test VolumeConfigurationResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libgds.models.volume_configuration_response.VolumeConfigurationResponse()  # noqa: E501
        if include_optional :
            return VolumeConfigurationResponse(
                name = '0', 
                tenant_id = '0', 
                sub_tenant_id = '0', 
                urn = '0', 
                online_status = 'Initializing', 
                error_code = '0', 
                error_message = '0', 
                time_of_last_error = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                created_by = '0', 
                time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                modified_by = '0', 
                object_store_settings = libica.openapi.libgds.models.object_store_settings.ObjectStoreSettings(
                    aws_s3 = libica.openapi.libgds.models.awss3_object_store_setting.AWSS3ObjectStoreSetting(
                        bucket_name = '012', 
                        key_prefix = 'gds-volumes/', ), 
                    # platform_credentials_name = '0',
                    secret_name='test',
                )
            )
        else :
            return VolumeConfigurationResponse(
        )

    def testVolumeConfigurationResponse(self):
        """Test VolumeConfigurationResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libconsole.configuration import Configuration


class TokenDetailResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'uid': 'str',
        'name': 'str',
        'username': 'str',
        'current_workgroup': 'Workgroup',
        'tid': 'str',
        'acls': 'list[str]',
        'domain': 'Domain'
    }

    attribute_map = {
        'uid': 'uid',
        'name': 'name',
        'username': 'username',
        'current_workgroup': 'currentWorkgroup',
        'tid': 'tid',
        'acls': 'acls',
        'domain': 'domain'
    }

    def __init__(self, uid=None, name=None, username=None, current_workgroup=None, tid=None, acls=None, domain=None, local_vars_configuration=None):  # noqa: E501
        """TokenDetailResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._uid = None
        self._name = None
        self._username = None
        self._current_workgroup = None
        self._tid = None
        self._acls = None
        self._domain = None
        self.discriminator = None

        if uid is not None:
            self.uid = uid
        if name is not None:
            self.name = name
        if username is not None:
            self.username = username
        if current_workgroup is not None:
            self.current_workgroup = current_workgroup
        if tid is not None:
            self.tid = tid
        if acls is not None:
            self.acls = acls
        if domain is not None:
            self.domain = domain

    @property
    def uid(self):
        """Gets the uid of this TokenDetailResponse.  # noqa: E501


        :return: The uid of this TokenDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._uid

    @uid.setter
    def uid(self, uid):
        """Sets the uid of this TokenDetailResponse.


        :param uid: The uid of this TokenDetailResponse.  # noqa: E501
        :type: str
        """

        self._uid = uid

    @property
    def name(self):
        """Gets the name of this TokenDetailResponse.  # noqa: E501


        :return: The name of this TokenDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this TokenDetailResponse.


        :param name: The name of this TokenDetailResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def username(self):
        """Gets the username of this TokenDetailResponse.  # noqa: E501


        :return: The username of this TokenDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._username

    @username.setter
    def username(self, username):
        """Sets the username of this TokenDetailResponse.


        :param username: The username of this TokenDetailResponse.  # noqa: E501
        :type: str
        """

        self._username = username

    @property
    def current_workgroup(self):
        """Gets the current_workgroup of this TokenDetailResponse.  # noqa: E501


        :return: The current_workgroup of this TokenDetailResponse.  # noqa: E501
        :rtype: Workgroup
        """
        return self._current_workgroup

    @current_workgroup.setter
    def current_workgroup(self, current_workgroup):
        """Sets the current_workgroup of this TokenDetailResponse.


        :param current_workgroup: The current_workgroup of this TokenDetailResponse.  # noqa: E501
        :type: Workgroup
        """

        self._current_workgroup = current_workgroup

    @property
    def tid(self):
        """Gets the tid of this TokenDetailResponse.  # noqa: E501


        :return: The tid of this TokenDetailResponse.  # noqa: E501
        :rtype: str
        """
        return self._tid

    @tid.setter
    def tid(self, tid):
        """Sets the tid of this TokenDetailResponse.


        :param tid: The tid of this TokenDetailResponse.  # noqa: E501
        :type: str
        """

        self._tid = tid

    @property
    def acls(self):
        """Gets the acls of this TokenDetailResponse.  # noqa: E501


        :return: The acls of this TokenDetailResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._acls

    @acls.setter
    def acls(self, acls):
        """Sets the acls of this TokenDetailResponse.


        :param acls: The acls of this TokenDetailResponse.  # noqa: E501
        :type: list[str]
        """

        self._acls = acls

    @property
    def domain(self):
        """Gets the domain of this TokenDetailResponse.  # noqa: E501


        :return: The domain of this TokenDetailResponse.  # noqa: E501
        :rtype: Domain
        """
        return self._domain

    @domain.setter
    def domain(self, domain):
        """Sets the domain of this TokenDetailResponse.


        :param domain: The domain of this TokenDetailResponse.  # noqa: E501
        :type: Domain
        """

        self._domain = domain

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, TokenDetailResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, TokenDetailResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.input_stream_settings import InputStreamSettings  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestInputStreamSettings(unittest.TestCase):
    """InputStreamSettings unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test InputStreamSettings
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.input_stream_settings.InputStreamSettings()  # noqa: E501
        if include_optional :
            return InputStreamSettings(
                access_pattern = 'sequential', 
                cache_size_gb = 5E+1, 
                block_size_mb = 0, 
                prefetch_blocks = 0
            )
        else :
            return InputStreamSettings(
        )

    def testInputStreamSettings(self):
        """Test InputStreamSettings"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libtes.configuration import Configuration


class InputStreamSettings(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'access_pattern': 'str',
        'cache_size_gb': 'int',
        'block_size_mb': 'float',
        'prefetch_blocks': 'int'
    }

    attribute_map = {
        'access_pattern': 'accessPattern',
        'cache_size_gb': 'cacheSizeGB',
        'block_size_mb': 'blockSizeMB',
        'prefetch_blocks': 'prefetchBlocks'
    }

    def __init__(self, access_pattern='sequential', cache_size_gb=50, block_size_mb=32.0, prefetch_blocks=32, local_vars_configuration=None):  # noqa: E501
        """InputStreamSettings - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._access_pattern = None
        self._cache_size_gb = None
        self._block_size_mb = None
        self._prefetch_blocks = None
        self.discriminator = None

        if access_pattern is not None:
            self.access_pattern = access_pattern
        if cache_size_gb is not None:
            self.cache_size_gb = cache_size_gb
        if block_size_mb is not None:
            self.block_size_mb = block_size_mb
        if prefetch_blocks is not None:
            self.prefetch_blocks = prefetch_blocks

    @property
    def access_pattern(self):
        """Gets the access_pattern of this InputStreamSettings.  # noqa: E501


        :return: The access_pattern of this InputStreamSettings.  # noqa: E501
        :rtype: str
        """
        return self._access_pattern

    @access_pattern.setter
    def access_pattern(self, access_pattern):
        """Sets the access_pattern of this InputStreamSettings.


        :param access_pattern: The access_pattern of this InputStreamSettings.  # noqa: E501
        :type: str
        """

        self._access_pattern = access_pattern

    @property
    def cache_size_gb(self):
        """Gets the cache_size_gb of this InputStreamSettings.  # noqa: E501


        :return: The cache_size_gb of this InputStreamSettings.  # noqa: E501
        :rtype: int
        """
        return self._cache_size_gb

    @cache_size_gb.setter
    def cache_size_gb(self, cache_size_gb):
        """Sets the cache_size_gb of this InputStreamSettings.


        :param cache_size_gb: The cache_size_gb of this InputStreamSettings.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                cache_size_gb is not None and cache_size_gb > 10000):  # noqa: E501
            raise ValueError("Invalid value for `cache_size_gb`, must be a value less than or equal to `10000`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                cache_size_gb is not None and cache_size_gb < 50):  # noqa: E501
            raise ValueError("Invalid value for `cache_size_gb`, must be a value greater than or equal to `50`")  # noqa: E501

        self._cache_size_gb = cache_size_gb

    @property
    def block_size_mb(self):
        """Gets the block_size_mb of this InputStreamSettings.  # noqa: E501


        :return: The block_size_mb of this InputStreamSettings.  # noqa: E501
        :rtype: float
        """
        return self._block_size_mb

    @block_size_mb.setter
    def block_size_mb(self, block_size_mb):
        """Sets the block_size_mb of this InputStreamSettings.


        :param block_size_mb: The block_size_mb of this InputStreamSettings.  # noqa: E501
        :type: float
        """
        if (self.local_vars_configuration.client_side_validation and
                block_size_mb is not None and block_size_mb > 1024):  # noqa: E501
            raise ValueError("Invalid value for `block_size_mb`, must be a value less than or equal to `1024`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                block_size_mb is not None and block_size_mb < 0):  # noqa: E501
            raise ValueError("Invalid value for `block_size_mb`, must be a value greater than or equal to `0`")  # noqa: E501

        self._block_size_mb = block_size_mb

    @property
    def prefetch_blocks(self):
        """Gets the prefetch_blocks of this InputStreamSettings.  # noqa: E501


        :return: The prefetch_blocks of this InputStreamSettings.  # noqa: E501
        :rtype: int
        """
        return self._prefetch_blocks

    @prefetch_blocks.setter
    def prefetch_blocks(self, prefetch_blocks):
        """Sets the prefetch_blocks of this InputStreamSettings.


        :param prefetch_blocks: The prefetch_blocks of this InputStreamSettings.  # noqa: E501
        :type: int
        """
        if (self.local_vars_configuration.client_side_validation and
                prefetch_blocks is not None and prefetch_blocks > 64):  # noqa: E501
            raise ValueError("Invalid value for `prefetch_blocks`, must be a value less than or equal to `64`")  # noqa: E501
        if (self.local_vars_configuration.client_side_validation and
                prefetch_blocks is not None and prefetch_blocks < 0):  # noqa: E501
            raise ValueError("Invalid value for `prefetch_blocks`, must be a value greater than or equal to `0`")  # noqa: E501

        self._prefetch_blocks = prefetch_blocks

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InputStreamSettings):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, InputStreamSettings):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Event Notification Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libens
from libica.openapi.libens.models.subscription import Subscription  # noqa: E501
from libica.openapi.libens.rest import ApiException

class TestSubscription(unittest.TestCase):
    """Subscription unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test Subscription
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libens.models.subscription.Subscription()  # noqa: E501
        if include_optional :
            return Subscription(
                id = '0', 
                urn = '0', 
                type = '0', 
                actions = [
                    '0'
                    ], 
                filter_expression = '0', 
                name = '0', 
                description = '0', 
                delivery_target = libica.openapi.libens.models.delivery_target.DeliveryTarget(
                    aws_sns_topic = libica.openapi.libens.models.delivery_target_aws_sns_topic.DeliveryTargetAwsSnsTopic(
                        topic_arn = '0', ), 
                    aws_sqs_queue = libica.openapi.libens.models.delivery_target_aws_sqs_queue.DeliveryTargetAwsSqsQueue(
                        queue_url = '0', ), 
                    workflow_run_launch = libica.openapi.libens.models.delivery_target_workflow_run_launch.DeliveryTargetWorkflowRunLaunch(
                        id = '0', 
                        version = '0', 
                        name = '0', 
                        # input = libica.openapi.libens.models.input.input(),
                    ),
                ),
                match_identities = [
                    '0'
                    ], 
                acl = [
                    '0'
                    ], 
                tenant_id = '0', 
                created_by_user_id = '0', 
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                deleted_by_user_id = '0', 
                time_deleted = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                is_deleted = True
            )
        else :
            return Subscription(
        )

    def testSubscription(self):
        """Test Subscription"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libgds
from libica.openapi.libgds.models.file_response import FileResponse  # noqa: E501
from libica.openapi.libgds.rest import ApiException

class TestFileResponse(unittest.TestCase):
    """FileResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test FileResponse
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libgds.models.file_response.FileResponse()  # noqa: E501
        if include_optional :
            return FileResponse(
                id = '0', 
                name = '0', 
                volume_id = '0', 
                volume_name = '0', 
                type = '0', 
                tenant_id = '0', 
                sub_tenant_id = '0', 
                path = '0', 
                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                created_by = '0', 
                time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                modified_by = '0', 
                inherited_acl = [
                    '0'
                    ], 
                urn = '0', 
                size_in_bytes = 56, 
                metadata = None, 
                is_uploaded = True, 
                archive_status = 'None', 
                time_archived = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                storage_tier = 'None', 
                e_tag = '0', 
                presigned_url = '0'
            )
        else :
            return FileResponse(
        )

    def testFileResponse(self):
        """Test FileResponse"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libwes
from libica.openapi.libwes.models.workflow_run_history_event_list import WorkflowRunHistoryEventList  # noqa: E501
from libica.openapi.libwes.rest import ApiException

class TestWorkflowRunHistoryEventList(unittest.TestCase):
    """WorkflowRunHistoryEventList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WorkflowRunHistoryEventList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libwes.models.workflow_run_history_event_list.WorkflowRunHistoryEventList()  # noqa: E501
        if include_optional :
            return WorkflowRunHistoryEventList(
                items = [
                    libica.openapi.libwes.models.workflow_run_history_event.WorkflowRunHistoryEvent(
                        name = '0', 
                        event_id = 56, 
                        previous_event_id = 56, 
                        event_type = '0', 
                        timestamp = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        # event_details = libica.openapi.libwes.models.event_details.eventDetails(),
                    )
                ],
                item_count = 56, 
                first_page_token = '0', 
                next_page_token = '0', 
                prev_page_token = '0', 
                last_page_token = '0', 
                total_item_count = 56, 
                total_page_count = 56
            )
        else :
            return WorkflowRunHistoryEventList(
        )

    def testWorkflowRunHistoryEventList(self):
        """Test WorkflowRunHistoryEventList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libwes
from libica.openapi.libwes.api.workflow_versions_api import WorkflowVersionsApi  # noqa: E501
from libica.openapi.libwes.rest import ApiException


class TestWorkflowVersionsApi(unittest.TestCase):
    """WorkflowVersionsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libwes.api.workflow_versions_api.WorkflowVersionsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_workflow_version(self):
        """Test case for create_workflow_version

        Create a new workflow version  # noqa: E501
        """
        pass

    def test_get_workflow_version(self):
        """Test case for get_workflow_version

        Get the details of a workflow version  # noqa: E501
        """
        pass

    def test_launch_workflow_version(self):
        """Test case for launch_workflow_version

        Launch a workflow version  # noqa: E501
        """
        pass

    def test_list_all_workflow_versions(self):
        """Test case for list_all_workflow_versions

        Get a list of all workflow versions  # noqa: E501
        """
        pass

    def test_list_workflow_versions(self):
        """Test case for list_workflow_versions

        Get a list of workflow versions  # noqa: E501
        """
        pass

    def test_update_workflow_version(self):
        """Test case for update_workflow_version

        Update an existing workflow version  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libtes
from libica.openapi.libtes.api.tasks_api import TasksApi  # noqa: E501
from libica.openapi.libtes.rest import ApiException


class TestTasksApi(unittest.TestCase):
    """TasksApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libtes.api.tasks_api.TasksApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_task(self):
        """Test case for create_task

        Create a Task  # noqa: E501
        """
        pass

    def test_get_task(self):
        """Test case for get_task

        Get the details of a Task  # noqa: E501
        """
        pass

    def test_list_tasks(self):
        """Test case for list_tasks

        Get a list of tasks  # noqa: E501
        """
        pass

    def test_update_task(self):
        """Test case for update_task

        Update an existing task.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libwes
from libica.openapi.libwes.models.workflow_signal_list import WorkflowSignalList  # noqa: E501
from libica.openapi.libwes.rest import ApiException

class TestWorkflowSignalList(unittest.TestCase):
    """WorkflowSignalList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test WorkflowSignalList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libwes.models.workflow_signal_list.WorkflowSignalList()  # noqa: E501
        if include_optional :
            return WorkflowSignalList(
                items = [
                    libica.openapi.libwes.models.workflow_signal_compact.WorkflowSignalCompact(
                        id = '0', 
                        urn = '0', 
                        href = '0', 
                        send_heartbeat_href = '0', 
                        send_success_response_href = '0', 
                        send_failure_response_href = '0', 
                        name = '0', 
                        status = '0', 
                        type = '0', 
                        description = '0', 
                        # inputs = libica.openapi.libwes.models.inputs.inputs(),
                        workflow_run = libica.openapi.libwes.models.workflow_run_compact.WorkflowRunCompact(
                            id = '0', 
                            urn = '0', 
                            href = '0', 
                            name = '0', 
                            time_started = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            time_stopped = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            status = '0', 
                            status_summary = '0', 
                            error = '0', 
                            error_cause = '0', 
                            workflow_version = libica.openapi.libwes.models.workflow_version_compact.WorkflowVersionCompact(
                                id = '0', 
                                urn = '0', 
                                href = '0', 
                                version = '0', 
                                category = '0', 
                                description = '0', 
                                language = libica.openapi.libwes.models.workflow_language.WorkflowLanguage(
                                    name = '0', 
                                    version = '0', ), 
                                status = '0', 
                                created_by_client_id = '0', 
                                time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                                created_by = '0', 
                                modified_by = '0', 
                                tenant_id = '0', 
                                acl = [
                                    '0'
                                    ], ), 
                            created_by_client_id = '0', 
                            time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            created_by = '0', 
                            modified_by = '0', 
                            tenant_id = '0', 
                            acl = [
                                '0'
                                ], ), 
                        timeout_seconds = 56, 
                        # result = libica.openapi.libwes.models.result.result(),
                        error = '0', 
                        error_cause = '0', 
                        created_by_client_id = '0', 
                        time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        created_by = '0', 
                        modified_by = '0', 
                        tenant_id = '0', 
                        acl = [
                            '0'
                            ], )
                    ], 
                item_count = 56, 
                first_page_token = '0', 
                next_page_token = '0', 
                prev_page_token = '0', 
                last_page_token = '0', 
                total_item_count = 56, 
                total_page_count = 56
            )
        else :
            return WorkflowSignalList(
        )

    def testWorkflowSignalList(self):
        """Test WorkflowSignalList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Task Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import libica.openapi.libtes
from libica.openapi.libtes.models.task_run_summary_paged_items import TaskRunSummaryPagedItems  # noqa: E501
from libica.openapi.libtes.rest import ApiException

class TestTaskRunSummaryPagedItems(unittest.TestCase):
    """TaskRunSummaryPagedItems unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test TaskRunSummaryPagedItems
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = libica.openapi.libtes.models.task_run_summary_paged_items.TaskRunSummaryPagedItems()  # noqa: E501
        if include_optional :
            return TaskRunSummaryPagedItems(
                items = [
                    libica.openapi.libtes.models.task_run_summary.TaskRunSummary(
                        id = '0', 
                        href = '0', 
                        urn = '0', 
                        name = '0', 
                        description = '0', 
                        status = 'Pending', 
                        status_details = '0', 
                        task_version_summary = libica.openapi.libtes.models.task_version_summary.TaskVersionSummary(
                            id = '0', 
                            href = '0', 
                            urn = '0', 
                            version = '0', 
                            description = '0', 
                            acl = [
                                '0'
                                ], 
                            tenant_id = '0', 
                            sub_tenant_id = '0', 
                            created_by = '0', 
                            time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                            modified_by = '0', 
                            time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), ), 
                        acl = [
                            '0'
                            ], 
                        tenant_id = '0', 
                        sub_tenant_id = '0', 
                        created_by = '0', 
                        time_created = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), 
                        modified_by = '0', 
                        time_modified = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'), )
                    ], 
                item_count = 56, 
                first_page_token = '0', 
                next_page_token = '0', 
                prev_page_token = '0', 
                last_page_token = '0', 
                total_item_count = 56, 
                total_page_count = 56
            )
        else :
            return TaskRunSummaryPagedItems(
        )

    def testTaskRunSummaryPagedItems(self):
        """Test TaskRunSummaryPagedItems"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from libica.openapi.libwes.api.workflow_runs_api import WorkflowRunsApi
from libica.openapi.libwes.api.workflow_signals_api import WorkflowSignalsApi
from libica.openapi.libwes.api.workflow_versions_api import WorkflowVersionsApi
from libica.openapi.libwes.api.workflows_api import WorkflowsApi



# coding: utf-8

"""
    Workflow Execution Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libwes
from libica.openapi.libwes.api.workflow_signals_api import WorkflowSignalsApi  # noqa: E501
from libica.openapi.libwes.rest import ApiException


class TestWorkflowSignalsApi(unittest.TestCase):
    """WorkflowSignalsApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libwes.api.workflow_signals_api.WorkflowSignalsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_fail_signal(self):
        """Test case for fail_signal

        Fail a workflow signal  # noqa: E501
        """
        pass

    def test_get_signal(self):
        """Test case for get_signal

        Get the details of a workflow signal  # noqa: E501
        """
        pass

    def test_list_signals(self):
        """Test case for list_signals

        Get a list of workflow signals  # noqa: E501
        """
        pass

    def test_succeed_signal(self):
        """Test case for succeed_signal

        Succeed a workflow signal  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Developer Console Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import libica.openapi.libconsole
from libica.openapi.libconsole.api.tokens_api import TokensApi  # noqa: E501
from libica.openapi.libconsole.rest import ApiException


class TestTokensApi(unittest.TestCase):
    """TokensApi unit test stubs"""

    def setUp(self):
        self.api = libica.openapi.libconsole.api.tokens_api.TokensApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_token(self):
        """Test case for create_token

        Creates a JWT token to call IAP services.  # noqa: E501
        """
        pass

    def test_get_token_details(self):
        """Test case for get_token_details

        Get current tokens info require authorization Bearer token  # noqa: E501
        """
        pass

    def test_refresh_token(self):
        """Test case for refresh_token

        Refresh session psToken.  # noqa: E501
        """
        pass

    def test_revoke_token(self):
        """Test case for revoke_token

        Revokes an access token.  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Genomic Data Store Service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from libica.openapi.libgds.configuration import Configuration


class FolderCopyRequest(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'target_parent_folder_id': 'str',
        'destination_folder_name': 'str'
    }

    attribute_map = {
        'target_parent_folder_id': 'targetParentFolderId',
        'destination_folder_name': 'destinationFolderName'
    }

    def __init__(self, target_parent_folder_id=None, destination_folder_name=None, local_vars_configuration=None):  # noqa: E501
        """FolderCopyRequest - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._target_parent_folder_id = None
        self._destination_folder_name = None
        self.discriminator = None

        self.target_parent_folder_id = target_parent_folder_id
        if destination_folder_name is not None:
            self.destination_folder_name = destination_folder_name

    @property
    def target_parent_folder_id(self):
        """Gets the target_parent_folder_id of this FolderCopyRequest.  # noqa: E501

        The parent folder into which the source folder will be copied.  # noqa: E501

        :return: The target_parent_folder_id of this FolderCopyRequest.  # noqa: E501
        :rtype: str
        """
        return self._target_parent_folder_id

    @target_parent_folder_id.setter
    def target_parent_folder_id(self, target_parent_folder_id):
        """Sets the target_parent_folder_id of this FolderCopyRequest.

        The parent folder into which the source folder will be copied.  # noqa: E501

        :param target_parent_folder_id: The target_parent_folder_id of this FolderCopyRequest.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and target_parent_folder_id is None:  # noqa: E501
            raise ValueError("Invalid value for `target_parent_folder_id`, must not be `None`")  # noqa: E501

        self._target_parent_folder_id = target_parent_folder_id

    @property
    def destination_folder_name(self):
        """Gets the destination_folder_name of this FolderCopyRequest.  # noqa: E501

        A new name for the destination folder. Required if target parent folder is the same as the destination folder.  When optional and not provided, the source folder name is used as the destination folder name.  # noqa: E501

        :return: The destination_folder_name of this FolderCopyRequest.  # noqa: E501
        :rtype: str
        """
        return self._destination_folder_name

    @destination_folder_name.setter
    def destination_folder_name(self, destination_folder_name):
        """Sets the destination_folder_name of this FolderCopyRequest.

        A new name for the destination folder. Required if target parent folder is the same as the destination folder.  When optional and not provided, the source folder name is used as the destination folder name.  # noqa: E501

        :param destination_folder_name: The destination_folder_name of this FolderCopyRequest.  # noqa: E501
        :type: str
        """
        if (self.local_vars_configuration.client_side_validation and
                destination_folder_name is not None and not re.search(r'^[^\/]+$', destination_folder_name)):  # noqa: E501
            raise ValueError(r"Invalid value for `destination_folder_name`, must be a follow pattern or equal to `/^[^\/]+$/`")  # noqa: E501

        self._destination_folder_name = destination_folder_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, FolderCopyRequest):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, FolderCopyRequest):
            return True

        return self.to_dict() != other.to_dict()



from setuptools import setup, find_packages
from libica import __version__

with open("README.md", "r") as fh:
    long_description = fh.read()

setup(
    name="libica",
    version=__version__,
    packages=find_packages(),
    url="https://github.com/umccr-illumina/libica",
    license="MIT",
    author="UMCCR and Contributors",
    author_email="services@umccr.org",
    description="Python SDK for Illumina Connected Analytics",
    long_description=long_description,
    long_description_content_type="text/markdown",
    python_requires=">=3.6",
    extras_require={
        "dev": [
            "pipdeptree",
            "twine",
            "setuptools",
            "wheel",
            "pdoc3",
            "mkdocs",
            "mkdocs-material",
        ],
        "test": [
            "pytest",
            "pytest-cov",
            "flake8",
            "mockito",
        ],
    },
    install_requires=[
        "requests",
        "python-dateutil",
        "six",
        "urllib3",
        "certifi",
    ],
)



from contextlib import closing
from unittest import TestCase

from libica.openapi import libwes
from libica.openapi.libwes import WorkflowList, WorkflowCompact, Workflow, WorkflowVersion, \
    UpdateWorkflowVersionRequest, WorkflowLanguage
from . import _logger, MOCK_EP


class LibWESIntegrationTests(TestCase):

    def setUp(self) -> None:
        super(LibWESIntegrationTests, self).setUp()

        ica_access_token = "MOCK"
        ica_base_url = MOCK_EP

        self.configuration = libwes.Configuration(
            host=ica_base_url,
            api_key={
                'Authorization': ica_access_token
            },
            api_key_prefix={
                'Authorization': "Bearer"
            },
        )

        with closing(libwes.ApiClient(self.configuration)) as _c:
            self.api_client = _c

    def tearDown(self) -> None:
        self.api_client.pool.close()

    def test_get_workflow(self):
        wfl_api: libwes.WorkflowsApi = libwes.WorkflowsApi(self.api_client)
        wfl_id = "mock"
        wfl: Workflow = wfl_api.get_workflow(workflow_id=wfl_id)
        self.assertIsNotNone(wfl)
        _logger.info(wfl.name)

    def test_list_workflows(self):
        wfl_api: libwes.WorkflowsApi = libwes.WorkflowsApi(self.api_client)
        try:
            page_token = None
            while True:
                wfl_list: WorkflowList = wfl_api.list_workflows(page_size=1000, page_token=page_token)
                self.assertIsNotNone(wfl_list.items)
                # _logger.info(wfl_list)
                for item in wfl_list.items:
                    wfl: WorkflowCompact = item
                    # _logger.info(wfl.id)
                    _logger.info(wfl.name)
                page_token = wfl_list.next_page_token
                if not wfl_list.next_page_token:
                    break
        except libwes.ApiException as e:
            _logger.error(e)

    def test_get_workflow_version(self):
        """
        python -m unittest tests.integration.test_libwes.LibWESIntegrationTests.test_get_workflow_version
        """
        wfv_api: libwes.WorkflowVersionsApi = libwes.WorkflowVersionsApi(self.api_client)
        wfv: WorkflowVersion = wfv_api.get_workflow_version(workflow_id="wfl.id_does_matter", version_name="v1")
        self.assertIsNotNone(wfv)
        _logger.info(wfv)

    def test_update_workflow_version(self):
        """
        python -m unittest tests.integration.test_libwes.LibWESIntegrationTests.test_update_workflow_version
        """
        wfv_api: libwes.WorkflowVersionsApi = libwes.WorkflowVersionsApi(self.api_client)

        current_wfv: WorkflowVersion = wfv_api.get_workflow_version(workflow_id="wfl.id", version_name="current_ver")
        desc = current_wfv.definition
        _logger.info(desc)

        body: UpdateWorkflowVersionRequest = UpdateWorkflowVersionRequest(
            version="0.2-redirect-nolisting",
            description="Uses sambamda slice and samtools to extract hla contigs, chr6 hla region and unmapped bams. "
                        "Align all to razers3 and then place through optitype workflow",
            language=WorkflowLanguage(name="CWL", version="1.1"),
            definition={'$graph': [{'class': "..."}]}
        )

        wfv: WorkflowVersion = wfv_api.update_workflow_version(
            workflow_id="wfl.id_does_matter", version_name="0.2-redirect-nolisting", body=body
        )

        self.assertIsNotNone(wfv)
        _logger.info(wfv)
